@@ -4,7 +4,7 @@ from stringmatch.strings import Strings
 def test_latinise():
     assert Strings().latinise("Héllö, world!") == "Hello, world!"
     assert Strings().latinise("ỲṖßɆȜǼǄ") == "YPssEYAEDZ"
-    assert Strings().latinise("ジャパニーズ") == "ziyapanizu"
+    assert Strings().latinise("ジャパニーズ") == "ziyapani-zu"
     assert Strings().latinise("「 ") == "[ "
 
 
